@@ -1,4 +1,4 @@
-#ident "$Id: goodies.c,v 4.1 1997/01/12 14:53:40 gert Exp $ Copyright (c) 1993 Gert Doering"
+#ident "$Id: goodies.c,v 4.5 2003/11/17 19:08:49 gert Exp $ Copyright (c) 1993 Gert Doering"
 
 /*
  * goodies.c
@@ -12,6 +12,7 @@
 #include "syslibs.h"
 #include <ctype.h>
 #include <string.h>
+#include <fcntl.h>
 #include <unistd.h>
 
 #include <sys/types.h>
@@ -31,12 +32,6 @@
 
 #ifdef SVR4
 # include <sys/procfs.h>
-# include <fcntl.h>
-#endif
-
-#ifdef linux
-# include <fcntl.h>
-# include <unistd.h>
 #endif
 
 /* get the base file name of a file path */
@@ -137,7 +132,8 @@ char * get_ps_args _P1 ((pid), int pid )
     return pscomm;
 #endif /* SVR4 */
 
-#ifdef linux
+#if defined(linux) || \
+	( defined(__FreeBSD__ ) && __FreeBSD_version >= 330000 )
 
 # ifdef DIALOUT_SHOW_USERNAMES
     char procfn[30];
@@ -195,6 +191,9 @@ char * get_ps_args _P1 ((pid), int pid )
     for ( i=0; i<l; i++ )
 	if ( psinfo[i] == 0 ) psinfo[i] = ' ';
 
+    /* remove trailing whitespace */
+    while( l>0 && isspace(psinfo[l-1]) ) psinfo[--l]='\0';
+
     return psinfo;
 
 # endif /* show user name, not process cmd line */
