@@ -1,4 +1,4 @@
-#ident "$Id: mgetty.c,v 4.32 2001/09/28 21:09:39 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.c,v 4.36 2003/11/17 19:08:20 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.c
  *
@@ -31,9 +31,6 @@
 
 #ifdef VOICE
 #include "voice/include/voice.h"
-# ifndef DIST_RING
-#  define DIST_RING
-# endif
 #endif
 
 /* how much time may pass between two RINGs until mgetty goes into */
@@ -65,7 +62,7 @@ chat_action_t	* answer_chat_actions = &ring_chat_actions[1];
  * system header files)
  */
 #if !defined(__NetBSD__) && !defined(__OpenBSD__)
-time_t		time _PROTO(( long * tloc ));
+time_t		time _PROTO(( time_t * tloc ));
 #endif
 
 /* logname.c */
@@ -356,7 +353,13 @@ int main _P2((argc, argv), int argc, char ** argv)
 #endif
     lprintf( L_MESG, "mgetty: %s", mgetty_version);
     lprintf( L_NOISE, "%s compiled at %s, %s", __FILE__, __DATE__, __TIME__ );
-    lprintf( L_NOISE, "user id: %d, parent pid: %d", getuid(), getppid());
+    i=getppid();
+    lprintf( L_NOISE, "user id: %d, pid: %d, parent pid: %d", getuid(), getpid(), i);
+    if ( i != 1 )
+    {
+        char *n = get_ps_args(i);
+	lprintf( L_WARN, "WARNING: parent process not init(pid=1), but pid=%d (%s)", i, n != NULL? n: "unknown" );
+    }
 	    
     /* read configuration file */
     mgetty_get_config( Device );
