@@ -10,7 +10,7 @@
  *
  * Marc
  *
- * $Id: Dolphin.c,v 1.7 1999/12/02 09:51:28 marcs Exp $
+ * $Id: Dolphin.c,v 1.8 2005/03/13 17:27:45 gert Exp $
  *
  */
 
@@ -140,6 +140,13 @@ voice_modem_struct Dolphin =
      (char *) IS_101_play_dtmf_cmd,
      (char *) IS_101_play_dtmf_extra,
      (char *) IS_101_play_dtmf_answr,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     NULL,  /* (char *) V253modem_start_duplex_voice_cmnd, */
+     NULL,  /* (char *) V253modemstart_duplex_voice_answr, */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_cmnd , */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_answr, */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
+
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -164,5 +171,9 @@ voice_modem_struct Dolphin =
      &IS_101_wait,
      &IS_101_play_dtmf,
      &IS_101_check_rmd_adequation,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     &IS_101_handle_duplex_voice,
+     NULL, /* since there is no way to enter duplex voice state */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      0
      };
