@@ -17,7 +17,7 @@
  * This file then adapted for the Multitec MT5600ZDXv by
  * Bill Nugent <whn@lopi.com>
  *
- * $Id: Multitech_5600ZDXv.c,v 1.4 1999/12/02 09:51:29 marcs Exp $
+ * $Id: Multitech_5600ZDXv.c,v 1.5 2005/03/13 17:27:46 gert Exp $
  *
  */
 
@@ -221,6 +221,13 @@ voice_modem_struct Multitech_5600ZDXv =
      (char *) IS_101_play_dtmf_cmd,
      (char *) IS_101_play_dtmf_extra,
      (char *) IS_101_play_dtmf_answr,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     NULL,  /* (char *) V253modem_start_duplex_voice_cmnd, */
+     NULL,  /* (char *) V253modemstart_duplex_voice_answr, */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_cmnd , */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_answr, */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
+
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -245,6 +252,10 @@ voice_modem_struct Multitech_5600ZDXv =
      &IS_101_wait,
      &IS_101_play_dtmf,
      &IS_101_check_rmd_adequation,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     &IS_101_handle_duplex_voice,
+     NULL, /* since there is no way to enter duplex voice state */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      0
      };
 
