@@ -4,7 +4,7 @@
  * Hacked by <Harlan.Stenn@pfcs.com>. Maybe will be merged
  * with the other Multitech driver.
  *
- * $Id: Multitech_5634ZPX.c,v 1.2 2001/12/22 16:08:01 marcs Exp $
+ * $Id: Multitech_5634ZPX.c,v 1.3 2005/03/13 17:27:46 gert Exp $
  *
  * Some functions can't be static because inherited by Multitech_5634ZPX_ISA.
  * Copied by md 2000/12/14
@@ -347,6 +347,12 @@ voice_modem_struct Multitech_5634ZPX =
      (char *) IS_101_play_dtmf_cmd,
      (char *) IS_101_play_dtmf_extra,
      (char *) IS_101_play_dtmf_answr,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     NULL,  /* (char *) V253modem_start_duplex_voice_cmnd, */
+     NULL,  /* (char *) V253modemstart_duplex_voice_answr, */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_cmnd , */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_answr, */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      &Multitech_5634ZPX_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -371,6 +377,10 @@ voice_modem_struct Multitech_5634ZPX =
      &IS_101_wait,
      &IS_101_play_dtmf,
      &IS_101_check_rmd_adequation,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     &IS_101_handle_duplex_voice,
+     NULL, /* since there is no way to enter duplex voice state */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      0
      };
 
