@@ -11,25 +11,20 @@
  *
  * New updated driver by Jens Adner <Jens.Adner@Wirtschaft.TU-Ilmenau.DE>.
  *
- * $Id: UMC.c,v 1.7 1999/06/15 13:04:01 marcs Exp $
+ * $Id: UMC.c,v 1.10 2005/03/13 17:27:46 gert Exp $
  *
  */
 
 #include "../include/voice.h"
 
 #define UMC_RELEASE "0.02"
-// #define UMC_VTS_WORKAROUND yes
+/* #define UMC_VTS_WORKAROUND yes */
 /* #define UMC_EXTENDED_DETECTION yes */
 #define UMC_SPEAKER_ON yes
 /* workaround: it should set by vgetty
  * ! program_name must be vgetty !
  */
 
-/*
- * <DLE><ETX> string
- */
-static char dletx[2]={ DLE, ETX };
-
 /*
  * Internal status variables for aborting some voice modem actions.
  */
@@ -281,6 +276,13 @@ voice_modem_struct UMC =
      (char *) IS_101_play_dtmf_cmd,
      (char *) IS_101_play_dtmf_extra,
      (char *) IS_101_play_dtmf_answr,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     NULL,  /* (char *) V253modem_start_duplex_voice_cmnd, */
+     NULL,  /* (char *) V253modemstart_duplex_voice_answr, */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_cmnd , */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_answr, */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
+
      &IS_101_answer_phone,
      &UMC_beep,
      &IS_101_dial,
@@ -304,6 +306,11 @@ voice_modem_struct UMC =
      &IS_101_voice_mode_on,
      &IS_101_wait,
      &IS_101_play_dtmf,
+     &IS_101_check_rmd_adequation,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     &IS_101_handle_duplex_voice,
+     NULL, /* since there is no way to enter duplex voice state */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      VMQ_NEEDS_SET_DEVICE_BEFORE_ANSWER /* steffen@informatik.tu-darmstadt.de */
      };
 
