@@ -3,7 +3,7 @@
  *
  * This file contains the ZyXEL 1496 specific hardware stuff.
  *
- * $Id: ZyXEL_1496.c,v 1.8 1999/12/02 09:51:30 marcs Exp $
+ * $Id: ZyXEL_1496.c,v 1.9 2005/03/13 17:27:46 gert Exp $
  *
  */
 
@@ -260,6 +260,13 @@ voice_modem_struct ZyXEL_1496 =
      (char *) IS_101_play_dtmf_cmd,
      (char *) IS_101_play_dtmf_extra,
      (char *) IS_101_play_dtmf_answr,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     NULL,  /* (char *) V253modem_start_duplex_voice_cmnd, */
+     NULL,  /* (char *) V253modemstart_duplex_voice_answr, */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_cmnd , */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_answr, */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
+
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -284,5 +291,9 @@ voice_modem_struct ZyXEL_1496 =
      &IS_101_wait,
      &IS_101_play_dtmf,
      &ZyXEL_1496_check_rmd_adequation,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     &IS_101_handle_duplex_voice,
+     NULL, /* since there is no way to enter duplex voice state */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      0
      };
